@@ -335,8 +335,51 @@ pub struct Inline;
 ///     a: &'a str,
 /// }
 /// ```
+#[deprecated = "Use `RefAsBox` for references, or `AsBox` for direct fields"]
+pub type Boxed = RefAsBox;
+
+/// A wrapper that serializes a field into a box.
+///
+/// This functions similarly to [`RefAsBox`], but is for regular fields instead of references.
+///
+/// # Example
+///
+/// ```
+/// use rkyv::{Archive, with::AsBox};
+///
+/// #[derive(Archive)]
+/// struct Example {
+///     #[with(AsBox)]
+///     a: i32,
+///     #[with(AsBox)]
+///     b: str,
+/// }
+/// ```
 #[derive(Debug)]
-pub struct Boxed;
+pub struct AsBox;
+
+/// A wrapper that serializes a reference as if it were boxed.
+///
+/// Unlike [`Inline`], unsized references can be serialized with `RefAsBox`.
+///
+/// References serialized with `RefAsBox` cannot be deserialized because the struct cannot own the
+/// deserialized value.
+///
+/// # Example
+///
+/// ```
+/// use rkyv::{Archive, with::RefAsBox};
+///
+/// #[derive(Archive)]
+/// struct Example<'a> {
+///     #[with(RefAsBox)]
+///     a: &'a i32,
+///     #[with(RefAsBox)]
+///     b: &'a str,
+/// }
+/// ```
+#[derive(Debug)]
+pub struct RefAsBox;
 
 /// A wrapper that attempts to convert a type to and from UTF-8.
 ///
@@ -460,5 +503,53 @@ pub struct AsVec;
 ///
 /// A common type combination is `Option<Box<T>>`. By using a null pointer, the archived version can
 /// save some space on-disk.
+///
+/// # Example
+///
+/// ```
+/// use core::mem::size_of;
+/// use rkyv::{Archive, Archived, with::Niche};
+///
+/// #[derive(Archive)]
+/// struct BasicExample {
+///     value: Option<Box<str>>,
+/// }
+///
+/// #[derive(Archive)]
+/// struct NichedExample {
+///     #[with(Niche)]
+///     value: Option<Box<str>>,
+/// }
+///
+/// assert!(size_of::<Archived<BasicExample>>() > size_of::<Archived<NichedExample>>());
+/// ```
 #[derive(Debug)]
 pub struct Niche;
+
+/// A wrapper that provides specialized, performant implementations of serialization and
+/// deserialization.
+///
+/// This wrapper can be used with containers like `Vec`, but care must be taken to ensure that they
+/// contain copy-safe types. Copy-safe types must be trivially copyable (have the same archived and
+/// unarchived representations) and contain no padding bytes. In situations where copying
+/// uninitialized bytes the output is acceptable, this wrapper may be used with containers of types
+/// that contain padding bytes.
+///
+/// # Safety
+///
+/// Using this wrapper with containers containing non-copy-safe types may result in undefined
+/// behavior.
+///
+/// # Example
+///
+/// ```
+/// use rkyv::{Archive, with::CopyOptimize};
+///
+/// #[derive(Archive)]
+/// struct Example {
+///     #[with(CopyOptimize)]
+///     bytes: Vec<u8>,
+/// }
+/// ```
+#[derive(Debug)]
+pub struct CopyOptimize;
